@@ -115,6 +115,8 @@ def pickle_kim_properties(properties=None,
             "unstable-stacking-fault-relaxed-energy-fcc-crystal-npt",
             "unstable-twinning-fault-relaxed-energy-fcc-crystal-npt",
             "verification-check",
+            "cohesive-potential-energy-crystal",
+            "crystal-structure-npt"
         ]
 
         # KIM property full IDs.
@@ -176,6 +178,8 @@ def pickle_kim_properties(properties=None,
             "tag:staff@noreply.openkim.org,2015-05-26:property/unstable-stacking-fault-relaxed-energy-fcc-crystal-npt",
             "tag:staff@noreply.openkim.org,2015-05-26:property/unstable-twinning-fault-relaxed-energy-fcc-crystal-npt",
             "tag:tadmor@noreply.openkim.org,2017-02-01:property/verification-check",
+            "tag:staff@noreply.openkim.org,2023-02-21:property/cohesive-potential-energy-crystal",
+            "tag:staff@noreply.openkim.org,2023-02-21:property/crystal-structure-npt"
         ]
 
         for _id in kim_property_ids:
