@@ -1,8 +1,5 @@
-import os
 from os.path import join, isfile
 
-import kim_edn
-
 from tests.test_kim_property import PyTest
 
 
@@ -88,6 +85,5 @@ class TestCreateModule:
                           1, join("tests", "fixtures", "atomic-mass.edn"))
 
 
-
 class TestPyTestCreateModule(TestCreateModule, PyTest):
     pass
