@@ -9,6 +9,8 @@ SOURCE_VALUE = [
     [0, 0, 0, 0, 0, 0, ],
     "P-1",
     ["P-1"],
+    ["fcc", ],
+    ["Cu"],
     0,
     8.00524023,
     96.73127369,
@@ -19,22 +21,26 @@ SOURCE_VALUE = [
 ]
 
 SOURCE_VALUE_TYPE = [
-    "float",  # [0, 0, 0, 0, 0, 0, ],
+    "float",   # [0, 0, 0, 0, 0, 0, ],
     "string",  # "P-1",
     "string",  # ["P-1"],
-    "float",  # 0,
-    "float",  # 8.00524023,
-    "float",  # 96.73127369,
-    "float",  # [[0.75, 0.251749, 0.149543, ], [0.75, 0.751749, 0.350457, ]],
+    "string",  # [ "fcc", ],
+    "string",  # [ "Cu" ],
+    "float",   # 0,
+    "float",   # 8.00524023,
+    "float",   # 96.73127369,
+    "float",   # [[0.75, 0.251749, 0.149543, ], [0.75, 0.751749, 0.350457, ]],
     "string",  # "P2_1/c",
     "string",  # ["Mn", "Mn", "Mn", "Mn"]
-    "bool",  # "False"
+    "bool",    # "False"
 ]
 
 SOURCE_VALUE_SCLAR = [
     False,  # [0, 0, 0, 0, 0, 0, ],
     True,  # "P-1",
     False,  # ["P-1"],
+    False,  # [ "fcc", ],
+    False,  # [ "Cu" ],
     True,  # 0,
     True,  # 8.00524023,
     True,  # 96.73127369,
@@ -48,6 +54,8 @@ SOURCE_VALUE_NDIMS = [
     1,  # [0, 0, 0, 0, 0, 0, ],
     0,  # "P-1",
     1,  # ["P-1"],
+    1,  # [ "fcc", ],
+    1,  # [ "Cu" ],
     0,  # 0,
     0,  # 8.00524023,
     0,  # 96.73127369,
@@ -123,6 +131,8 @@ class TestPropertyInstanceModuleComponents:
             self.kim_property.check_optional_key_source_value_scalar(1.0, "string"))
         self.assertFalse(
             self.kim_property.check_optional_key_source_value_scalar(1.0, "file"))
+        self.assertFalse(
+            self.kim_property.check_optional_key_source_value_scalar(1.0, "unknown"))
 
         # input is int but type is float, or bool or different
         self.assertTrue(
@@ -139,6 +149,8 @@ class TestPropertyInstanceModuleComponents:
             self.kim_property.check_optional_key_source_value_scalar(1, "string"))
         self.assertFalse(
             self.kim_property.check_optional_key_source_value_scalar(1, "file"))
+        self.assertFalse(
+            self.kim_property.check_optional_key_source_value_scalar(1, "unknown"))
 
         # input is str but type file or is different
         self.assertTrue(
@@ -153,13 +165,15 @@ class TestPropertyInstanceModuleComponents:
             self.kim_property.check_optional_key_source_value_scalar("Al", "list"))
         self.assertFalse(
             self.kim_property.check_optional_key_source_value_scalar("Al", "bool"))
+        self.assertFalse(
+            self.kim_property.check_optional_key_source_value_scalar("Al", "unknown"))
 
         # input is bool but type is different
         self.assertTrue(
             self.kim_property.check_optional_key_source_value_scalar(True, "bool"))
-        self.assertTrue(
+        self.assertFalse(
             self.kim_property.check_optional_key_source_value_scalar(True, "int"))
-        self.assertTrue(
+        self.assertFalse(
             self.kim_property.check_optional_key_source_value_scalar(True, "float"))
         self.assertFalse(
             self.kim_property.check_optional_key_source_value_scalar(True, "file"))
@@ -167,6 +181,8 @@ class TestPropertyInstanceModuleComponents:
             self.kim_property.check_optional_key_source_value_scalar(True, "string"))
         self.assertFalse(
             self.kim_property.check_optional_key_source_value_scalar(True, "list"))
+        self.assertFalse(
+            self.kim_property.check_optional_key_source_value_scalar(True, "unknown"))
 
     def test_get_optional_key_source_value_ndimensions(self):
         """Test the source-value ndimensions component."""
@@ -273,10 +289,24 @@ class TestPropertyInstanceModuleComponents:
     def test_check_instance_optional_key_marked_required_are_present(self):
         """Test the inctances optional presence of the keys marked as required."""
         import kim_edn
+        # property instance is not a dict
+        pi = ["property-id"]
+        pd = kim_edn.load(
+            join("tests", "fixtures", "cohesive-energy-relation-cubic-crystal.edn"))
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.check_instance_optional_key_marked_required_are_present,
+                          pi, pd)
+
+        # property definition is not a dict
+        pi = {"property-id": "tag:staff@noreply.openkim.org,2014-04-15:property/cohesive-energy-relation-cubic-crystal", "instance-id": 1}
+        pd = ["property-id"]
+        self.assertRaises(self.KIMPropertyError,
+                          self.kim_property.check_instance_optional_key_marked_required_are_present,
+                          pi, pd)
+
         pi = {"property-id": "tag:staff@noreply.openkim.org,2014-04-15:property/cohesive-energy-relation-cubic-crystal", "instance-id": 1}
         pd = kim_edn.load(
             join("tests", "fixtures", "cohesive-energy-relation-cubic-crystal.edn"))
-
         self.assertRaises(self.KIMPropertyError,
                           self.kim_property.check_instance_optional_key_marked_required_are_present,
                           pi, pd)
@@ -317,6 +347,26 @@ class TestPropertyInstanceModuleComponents:
         self.assertRaises(self.KIMPropertyError, self.kim_property.check_property_instances,
                           pi, fp=pd, fp_path="cohesive-energy-relation-cubic-crystal.edn")
 
+        # Fails if unable to find a KIM property definitio
+        pi = {"property-id": "tag:staff@noreply.openkim.org,2014-05-21:property/surface-energy-broken-bond-fit-cubic-bravais-crystal-npt",
+              "instance-id": 1}
+        self.assertRaises(self.KIMPropertyError, self.kim_property.check_property_instances,
+                          pi, fp=None, fp_path=join("tests", "fixtures"))
+
+        fp = '{"property-id" "tag:brunnels@noreply.openkim.org,2016-05-11:property/atomic-mass" "property-title" "Atomic mass" "property-description" "The atomic mass of the element" "species" {"type" "string" "has-unit" false "extent" [] "required" true "description" "Element symbol of the species"} "mass" {"type" "float" "has-unit" true "extent" [] "required" true "description" "Mass of a single atom of the species"}}'
+        pi = '[{"property-id" "tag:brunnels@noreply.openkim.org,2016-05-11:property/atomic-mass" "instance-id" 1 "species" {"source-value" "Ar"} "mass" {"source-value" 39.948 "source-unit" "grams/mole"}}]'
+        try:
+            self.kim_property.check_property_instances(pi, fp=fp)
+            passed = True
+        except:
+            passed = False
+        self.assertTrue(passed)
+
+        # check if required keys are there
+        fp = '{"property-id" "tag:brunnels@noreply.openkim.org,2016-05-11:property/atomic-mass"}'
+        self.assertRaises(self.KIMPropertyError, self.kim_property.check_property_instances,
+                          pi, fp=fp)
+
 
 property_instance_names = [
     "RD_000018659700_000_data.edn",
